Monty Python's Flying Circus: Just the Words - Episode 30

# Episode Thirty

'Blood, Devastation, Death, War and Horror'
The man who speaks in anagrams
Anagram quiz
Merchant banker
Pantomime horses
Life and death struggles
Mary recruitment office
Bus conductor sketch
The man who makes people laugh uncontrollably
Army captain as clown
Gestures to indicate pauses in a televised talk
Neurotic announcers
The news with Richard Baker
'The Pantomime Horse is a Secret Agent'

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| Stock colour film of vivid explosive action for fifteen seconds: dog fight RAF style; trains crashing; Spanish hotel blowing up; car crashing and exploding; train on collapsing bridge; volcano erupting; Torrey Canyon burning; forest fire blazing. From this we zoom the following words individually:
| CAPTION: 'BLOOD, DEATH, WAR, HORROR'
| Cut to an interviewer in a rather dinky little set. On the wall there is a rather prettily done sign, not too big, saying 'Blood, Devastation, Death, War and Horror', as if it were a show's title.
Interviewer | Hello, good evening and welcome to another edition of Blood, Devastation, Death War and Horror, and later on we'll be meeting a man who does gardening. But first on the show we've got a man who speaks entirely in anagrams.
Man | Taht si crreoct.
Interviewer | Do you enjoy it?
Man | I stom certainly od. Revy chum so.
Interviewer | And what's your name?
Man | Hamrag - Hamrag Yatlerot.
Interviewer | Well, Graham, nice to have you on the show. Now, where do you come from?
Man | Bumcreland.
Interviewer | Cumberland?
Man | Staht sit sepreicly.
Interviewer | And I believe you're working on an anagram version of Shakespeare?
Man | Sey, sey - taht si crreoct, er. Ta the mnemot I'm wroking on 'The Mating of the Wersh'.
Interviewer | 'The Mating of the Wersh'? By William Shakespeare?
Man | Nay, by Malliwi Rapesheake.
Interviewer | And what else?
Man | 'Two Netlemeg of Verona', 'Twelfth Thing', 'The Chamrent of Venice'....
Interviewer | Have you done 'Hamlet'?
Man | 'Thamle'. 'Be ot or bot ne ot, tath is the nestquie.'
Interviewer | And what is your next project?
Man | 'Ring Kichard the Thrid'.
Interviewer | I'm sorry?
Man | 'A shroe! A shroe! My dingkome for a shroe!'
Interviewer | Ah, Ring Kichard, yes... but surely that's not an anagram, that's a spoonerism.
Man | If you're going to split hairs, I'm going to piss off. (he leaves)
| Cut to the naked organist (Terry J), then to the announcer.
Announcer | And now...
It's Man | It's...
| Animated titles, title given as:
Voice Over | Tony M. Nyphot's Flying Risccu.
| CAPTION: 'CHAMRAN KNEBT'
| Pull out a little. The board has little green curtains and there is a pepperpot standing in front of it.
Presenter | Mrs Scab, you have twelve hours to beat the clock.
| A gong rings. A superimposed clock starts to move incredibly fast. It has a minute hand and an hour hand. Twelve hours pass very quickly. The pepperpot starts to rearrange the letters, very quickly. She gets it right. It reads: 'merchant bank'. The gong again and and the clock stops.
Presenter | Correct!
Pepperpot | I've done it. I've done it. Ha, ha, ha!
| An enormous head of a large cartoon-type hammer hits her and she goes down very fast.
| Cut to a city gent in his office. A sign on his desk says a 'Charman Knebter'. He is waiting to answer his phone. It rings; he answers.
City Gent | Hello? Ah, Mr Victim, I'm glad to say that I've got the go-ahead to lend you the money you require. Yes, of course we will want as security the deeds of your house, of your aunt's house, of your second cousin's house, of your wife's parents' house, and of your grannie's bungalow, and we will in addition need a controlling interest in your new company, unrestricted access to your private bank account, the deposit in our vaults of your three children as hostages and a full legal indemnity against any acts of embezzlement carried out against you by any members of our staff during the normal course of their duties... no, I'm afraid we couldn't accept your dog instead of your youngest child, we would like to suggest a brand new scheme of ours under which 51% of both your dog and your wife pass to us in the event of your suffering a serious accident. Fine. No, not at all, nice to do business with you. (puts the phone down, speaks on intercom) Miss Godfrey, could you send in Mr Ford please. (to himself) Now where's that dictionary. ah yes - here we are, inner life... inner life ... (a knock on the door) Come in. (Mr Ford enters, he is collecting for charity with a tin) Ah, Mr Ford isn't it?
Mr Ford | That's right.
City Gent | How do you do. I'm a merchant banker.
Mr Ford | How do you do Mr...
City Gent | Er... I forget my name for the moment but I am a merchant banker.
Mr Ford | Oh. I wondered whether you'd like to contribute to the orphan's home. (he rattles the tin)
City Gent | Well I don't want to show my hand too early, but actually here at Slater Nazi we are quite keen to get into orphans, you know, developing market and all that... what sort of sum did you have in mind?
Mr Ford | Well... er... you're a rich man.
City Gent | Yes, I am. Yes. Yes, very very rich. Quite phenomenally wealthy. Yes, I do own the most startling quantifies of cash. Yes, quite right... you're rather a smart young lad aren't you. We could do with somebody like you to feed the pantomime horse. Very smart.
Mr Ford | Thank you, sir.
City Gent | Now, you were saying. I'm very, very, very, very, very, very, very, very, very, very, very rich.
Mr Ford | So er, how about a pound?
City Gent | A pound. Yes, I see. Now this loan would be secured by the...
Mr Ford | It's not a loan, sir.
City Gent | What?
Mr Ford | It's not a loan.
City Gent | Ah.
Mr Ford | You get one of these, sir. (he gives him a flag)
City Gent | It's a bit small for a share certificate isn't it? Look, I think I'd better run this over to our legal department. If you could possibly pop back on Friday...
Mr Ford | Well do you have to do that, couldn't you just give me the pound?
City Gent | Yes, but you see I don't know what it's for.
Mr Ford | It's for the orphans.
City Gent | Yes?
Mr Ford | It's a gift.
City Gent | A what?
Mr Ford | A gift.
City Gent | Oh a gift!
Mr Ford | Yes.
City Gent | A tax dodge.
Mr Ford | No, no, no, no.
City Gent | No? Well, I'm awfully sorry I don't understand. Can you just explain exactly what you want.
Mr Ford | Well, I want you to give me a pound, and then I go away and give it to the orphans.
City Gent | Yes?
Mr Ford | Well, that's it.
City Gent | No, no, no, I don't follow this at all, I mean, I don't want to seem stupid but it looks to me as though I'm a pound down on the whole deal.
Mr Ford | Well, yes you are.
City Gent | I am! Well, what is my incentive to give you the pound?
Mr Ford | Well the incentive is - to make the orphans happy.
City Gent | (genuinely puzzled) Happy?... You quite sure you've got this right?
Mr Ford | Yes, lots of people give me money.
City Gent | What, just like that?
Mr Ford | Yes.
City Gent | Must be sick. I don't suppose you could give me a list of their names and addresses could you?
Mr Ford | No, I just go up to them in the street and ask.
City Gent | Good lord! That's the most exciting new idea I've heard in years! It's so simple it's brilliant! Well, if that idea of yours isn't worth a pound I'd like to know what is. (he takes the tin from Ford)
Mr Ford | Oh, thank you, sir.
City Gent | The only trouble is, you gave me the idea before I'd given you the pound. And that's not good business.
Mr Ford | Isn't it?
City Gent | No, I'm afraid it isn't. So, um, off you go. (he pulls a lever opening a trap door under Ford's feet and Ford falls through with a yelp) Nice to do business with you.
| Cut briefly to a Mongol.
Mongol | Anyway.
| Cut back to the banker.
City Gent | And off we go again. (he goes to the intercom) Ah Miss Godfrey could yould send in the pantomime horses please.
| The door opens and two pantomime horses run in. Pantomime music. They do a routine including running round the room and bumping into each other. They then stand in front of the city gent crossing their legs and putting their heads on one side.
City Gent | Now I've asked you to ... (they repeat the routine) Now I've asked you ... (they start again) Shut up! (they stop) Now I've asked you in here to see me this morning because I'm afraid we're going to have to let one of you go. (the pantomime horses heads go up, their ears waggle and their eyes go round) I'm very sorry but the present rationalization of this firm makes it inevitable that we hive one of you off. (water spurts out of their eyes in a stream) Now you may think that this is very harsh behaviour but let me tell you that our management consultants actually queried the necessity for us to employ a pantomime horse at all. (the horses register surprise and generally behave ostentatiously) And so the decision has to be made which one of you is to go. Champion... how many years have you been with this firm? (Champion stamps his foot three times) Trigger? (Trigger stamps his front foot twice and rear foot once) I see. Well, it's a difficult decision. But in accordance with our traditional principles of free enterprise and healthy competition I'm going to ask the two of you to fight to the death for it. (one of the horses runs up to him and puts his head by the city gent's ear) No, I'm afraid there's no redundancy scheme.
| The horses turn and start kicking each other on the shins. After a few blows:
Voice Over | (German accent) In the hard and unrelenting world of nature the ceaseless struggle for survival continues. (one of the pantomime horses turns tail and runs out) This time one of the pantomime horses concedes defeat and so lives to fight another day. (cut to stock film of sea lions fighting) Here, in a colony of sea lions, we see a huge bull sea lion seeing off an intruding bull who is attempting to intrude on his harem. This pattern of aggressive behaviour is typical of these documentaries. (cut to shot of two almost stationary limpets) Here we see two limpets locked in a life or death struggle for territory. The huge bull limpet, enraged by the rock, endeavours to encircle its sprightly opponent. (shot of wolf standing still) Here we see an ant. This ant is engaged in a life or death struggle with the wolf. You can see the ant creeping up on the wolf on all sixes. (a moving arrow is superimposed) Now he stops to observe. Satisfied that the wolf has not heard him, he approaches nearer. With great skill he chooses his moment and then, quick as a limpet, with one mighty bound (the arrow moves to the wolf's throat; the wolf does not move) buries his fangs in the wolf's neck. The wolf struggles to no avail. A battle of this kind can take anything up to fifteen years because the timber ant has such a tiny mouth. (distant shot of two men fighting violently) Here we see Heinz Sielmann engaged in a life or death struggle with Peter Scott. They are engaged in a bitter punch-up over repeat fees on the overseas sales of their nature documentaries. (another man joins in) Now they have been joined by an enraged Jacques Cousteau. This is typical of the harsh and bitchy world of television features. (shot of honey bear sitting about aimlessly) Here we see a honey bear not engaged in a life or death struggle about anything. These honey bears are placid and peaceful creatures and consequently bad television. (shot of pantomime horse running along in a wood) Here we see a pantomime horse. It is engaged in a life or death struggle for a job with a merchant bank. However, his rival employee, the huge bull pantomime horse, is lying in wait for him. (pantomime horse behind tree drops sixteen-ton weight on the horse running under the tree) Poor pantomime horse. (shot of pantomime goose behind a small tree with a bow and arrow) Here we see a pantomime goose engaged in a life or death struggle with Terence Rattigan. (we see Terrace walking along) The enraged goose fires. (the goose fires and hits Terence in the neck; Terrace looks amazed and dies) Poor Terence. Another victim of this silly film. (shot of an amazing-looking large woman with a crown waiting in the undergrowth by the side of a path) Here we see an enraged pantomime Princess Margaret, she is lying in wait for her breakfast. (a breakfast tray appears being pulled along the path by a length of wire) The unsuspecting breakfast glides ever closer to its doom. The enraged pantomime royal person is poised for the kill. She raises her harpoon and fires. (the pantomime Princess Margaret does so, hurling the harpoon at the moving tray) Pang! Right in the toast. A brief struggle and all is over. Poor breakfast! Another victim of the.... aargh!
| ANIMATION: which begins by showing the sudden demise of the previous voice over and continues with the story of a carnivorous house.
| CAPTION: 'THE MAKERS OF THIS FILM WOULD LIKE TO THANK THE FOLLOWING PEOPLE WHO GAVE US LOTS OF MONEY TO SEE THEIR NAMES IN LIGHTS: VICTOR - HIS FRIEND BOBBY - AND - MARY
| Pull back to show that 'Mary' is part of a sign saying: 'Mary Recruitment Office'. Pull out to reveal that it is a sign over a shop as for army recruiting office. An RSM with waxed moustache and snappy straight-against-the-forehead peaked cap comes out of the shop. He hangs a clearly printed sign on a nail on the door. It reads: 'Sketch just starting - actor wanted'.
Voice Over | Sketch just starting, actor wanted.
| The RSM looks up and down the road, glances up at the sign above his shop without noticing it. He goes inside again. A man walks up, reads the sign and enters. He is Mr Man.
Mr Man | Good morning.
RSM | Morning, sir.
Mr Man | I'd like to join the army please.
RSM | I see. Short service or long service commission, sir?
Mr Man | As long as possible please.
RSM | Right well I'll just take a few particulars and then...
| Suddenly he looks as though a dim memory has penetrated his skull. He breaks off, looking thoughtful, walks towards the door and exits. He comes out of shop, looks up at word 'Mary', tuts and changes the letters round to read 'Army'. He suddenly looks round and we see a queue of nuns.
RSM | Shove off! (he goes back inside) Then there'll be a few forms to sign, and of course we'll need references and then a full medical examination by the ...
Mr Man | Yes. Yes, yes I see. (diffidently) I was just wondering whether it would be possible for me to join... the women's army?
RSM | The Women's Royal Army Corps, sir?
Mr Man | Yes. I was just thinking, you know, if it was possible for me to have my choice ... I'd prefer to be in the Women's Royal Amy Corps.
RSM | Well, I'm afraid that the people that recruit here normally go straight into the Scots Guards.
Mr Man | Which is all... men... I suppose?
RSM | Yes it is.
Mr Man | Yes. Are there any regiments which are more effeminate than others?
RSM | Well, no sir. I mean, apart from the Marines, they're all dead butch.
Mr Man | You see, what I really wanted was a regiment where I could be really quiet and have more time to myself to work with fabrics, and creating new concepts in interior design.
RSM | Working with fabrics and experimenting with interior design!
Mr Man | Yes.
RSM | Oh well you want the Durham Light Infantry then, sir.
Mr Man | Oh.
RSM | Oh yes. That's the only regiment that's really doing something new with interior design, with colour, texture, line and that.
Mr Man | I see.
RSM | Oh yes, I mean their use of colour with fabrics is fantastic. I saw their pattern book the other day - beautiful, beautiful. Savage tans, great slabs of black set against aggressive orange. It really makes you want to shout out, this is good! This is real!
Mr Man | Really?
RSM | Oh yes. I mean the Inniskillin Fusiliers and the Anglian Regiment are all right if you're interested in the art nouveau William Morris revival bit, but if you really want a regiment of the line that is really saying something about interior decor, then you've got to go for the Durham Light Infantry.
Mr Man | Oh, I've had enough of this. I'm handing in my notice.
RSM | What do you mean?
Mr Man | Well I mean, when I applied for this job I thought I'd get a few decent lines but you end up doing the whole thing. I mean my last five speeches have been 'really, really - I see - I see' and 'really'. I wouldn't give those lines to a dog.
RSM | All right, all right, all right, sonny. I'll tell you what. We'll do something different. I'll be a bus conductor, and you can be a really funny passenger on a bus.
| Cut to a bus set. There is a very bad backcloth of the interior of the top deck of a bus. It looks like the set for a rather tatty revue. On the cut Mr Man is standing in exactly the same place as he was - so that it looks as if the scene has changed around him. The RSM appears from one side. He is still dressed basically as an RSM but has a few bus conductor things such as a ticket machine, money satchel and a big arrow through his neck. He talks like a music-hall comedian.
RSM | Any more fares please? I've got a chauffeur and every time I go to the lavatory he drives me potty! Boom-boom! One in a row (sings) I'm not unusual. I'm just...
Mr Man | Fivepenny please.
RSM | Five beautiful pennies going in to the bag... and you are the lucky winner of... one fivepenny ticket! (hands him a ticket) What's the Welshman doing under the bed? He's having a leak! Oh they're all in here tonight. (brief film clip of audience laughing)
Mr Man | Look!
RSM | I am looking - it's the only way I keep my eyelids apart! Boom-boom! Every one a Maserati!
Mr Man | Look! You said I was going to be a funny passenger.
RSM | (snapping out of music-hall manner) What do you mean?
Mr Man | I mean, all I said was, fivepenny please, You can't call that a funny line.
RSM | Well it's the way you said it.
Mr Man | No it isn't. Nobody can say 'fivepenny please' and make it funny.
| Cut to vox pop of city gent in a busy street.
City Gent | Fivepenny please.
| Cut to stock film of audience rolling about with laughter and clapping. Cut back to vox pop of city gent in street. He looks rather bewildered. He shrugs, turns and as he starts to walk away the camera pulls out. We see the city gent pass two colleagues.
City Gent | Morning.
| They collapse laughing and roll about on the pavement. The city gent hurries on, and turns into the door of a big office block. Cut to the foyer. A hall porter is standing behind a counter.
City Gent | Not so warm today, George.
| A shriek of mirth from the porter who collapses behind the counter. The city gent continues walking into the lift. There are two other city gents and one secretary already in the lift. The doors shut.
Man's Voice | Good morning.
Secretary's Voice | Good morning.
City Gent's Voice | Good morning.
| Shrieks of laughter. Cut to the doors of the lift on the third floor. Lift doors open and the city gent steps out rather quickly looking embarrassed. Behind him he leaves the three collapsed with mirth on the floor. The lift doors shut and the lift goes down again. Cut to interior of boss's office. A knock on the door. The boss is standing with his back to the door desperately preparing himself to keep a straight face.
Boss | Come in, Mr Horton.
| The city gent enters.
City Gent | Morning, sir.
Boss | Do - do sit down. (he indicates chair, trying not to look at the city gent)
City Gent | Thank you, sir.
| The boss starts to snigger but suppresses it with feat of self-control.
Boss | Now then Horton, you've been with us for twenty years, and your work in the accounts department has been immaculate (the city gent starts to speak; the boss suppresses another burst of laughter) No no - please don't say anything. As I say, your work has been beyond reproach, but unfortunately the effect you have on your colleagues has undermined the competence (almost starts laughing) ... has undermined the competence of this firm to such a point that I'm afraid that I've got no option but to sack you.
City Gent | (in a broken voice) I'm sorry to hear that, sir. (the boss giggles, gets up hastily and turning his back on city gent leans against the mantelpiece; his desire to laugh mounts through the next speech) It couldn't have come at a worse time. There's school fees for the two boys coming up, and the wife's treatment costing more now ... I don't know where the money's coming from as it is. And now I don't see any future ... I'd been hoping I'd be able to hang on here just for the last couple of years but... now ... I just want to go out and end it all.
| The boss cannot control himself any longer. He collapses in helpless mirth, falling all over the room. Immediately we cut to stock film of terrific audience laughter.
| Cut to backdrop of a circus ring. In front of it, as if in the ring, stand the RSM and Mr Man. Mr Man is as before. The RSM is dressed the same except that over his uniform he wears baggy trousers and braces and a funny nose. He is responding to the audience applause. Mr Man has obviously just been drenched with hot water - he is soaked and steam is rising.
RSM | Thank you! Thank you! Thank you! Thank you and now for the fish - the fish down the trousers. (the RSM picks up fish and puts it down Mr Man's trousers) It's your laugh mate it's not mine. It's your trousers - not my trousers - it's your trousers - and now for the whitewash. (the RSM pours a bucket of whitewash over him) The whitewash over you - not over me. It's over you. You get the laugh. You get all the laughs. And now for the custard pie in the mush. (more laughter, the RSM puts custard pie in his face and knees him in the balls) It's not my mush - it's your mush. It's your laugh - it's your laugh mate - not mine. It's your bleeding laugh.
| Cut to stock film of Mr Heath laughing followed by stock film of Women's Institute applauding.
| CAPTION: 'THE BOLS STORY'
| CAPTION: 'THE STORY OF HOLLAND'S MOST FAMOUS APERITIF'
| Mr Orbiter-5 is sitting in a swivel chair facing camera in a TV presentation set. Behind him is a set with enormous lettering which says 'Is the Queen sane?' Zoom in on Mr Orbiter-5. He starts talking immediately
Mr Orbiter | Good evening. Well tonight, we are going to talk about... well that is... I am going to talk about... well actually I am talking about it now... well I'm not talking about it now, but I am talking... I know I'm pausing occasionally, and not talking during the pauses, but the pauses are part of the whole process of talking... when one talks one has to pause... er ... like then! I paused ... but I was still talking ... and again there! No the real point of what I'm saying is that when I appear not to be talking don't go nipping out to the kitchen, putting the kettle on ... buttering scones... or getting crumbs and bits of food out of those round brown straw mats that the teapot goes on... because in all probability I'm still talking and what you heard was a pause ... er ... like there again. Look! To make it absolutely easier, so there's no problem at all, what I'll do, I'll give you some kind of sign, like this (makes a gesture) while I'm still talking, and only pausing in between words... and when I've finished altogether I'll do this. (he sits upright and crosses his arms) All right?
| SUPERIMPOSED CAPTION: 'THE END'
Mr Orbiter | No, no! No sorry - just demonstrating... haven't finished. Haven't started yet. (the caption is removed; he sits and tries to gather his thoughts then suddenly, remembers) Oh dear. (does the gesture hastily) Nearly forgot the gesture. Hope none of you are nipping out into the kitchen, getting bits of food out of those round brown mats which the teapot... Good evening (gesture) Tonight I want to talk about...
| Cut to the BBC world symbol.
Adrian | (voice over) We interrupt this programme to annoy you and make things generally irritating for you.
| Cut back to Mr Orbiter-5.
Mr Orbiter | ... with a large piece of wet paper. (gesture) Turn the paper over - turn the paper over keeping your eye on the camel, and paste down the edge of the sailor's uniform, until the word 'Maudling' is almost totally obscured. (gesture) Well, that's one way of doing it. (gesture)
| Cut to the BBC world symbol again and hold throughout the following dialogue.
Adrian | (voice over) Good evening, we interrupt this programme again, a) to irritate you and, b) to provide work for one of our announcers.
Jack | (voice over) Good evening, I'm the announcer who's just been given this job by the BBC and I'd just like to say how grateful I am to the BBC for providing me with work, particularly at this time of year, when things are a bit thin for us announcers... um... I don't know whether I should tell you this, but, well, I have been going through a rather tough time recently. Things have been pretty awful at home. My wife, Josephine... 'Joe-jums' as I call her ... who is also an announcer...
Joe-jums | Hello.
Jack | ... has not been able to announce since our youngest, Clifford, was born, and, well, (tearfully) I've just got no confidence left... I can't get up in the morning... I feel there's nothing worth living for... (he starts to sob)
Dick | Hello, I'm another announcer, my name's Dick. Joe-jums just rang me and said Jack was having a bad time with this announcement, so I've just come to give him a hand. How is he, Joe-jums?
Joe-jums | Pretty bad, Dick.
Dick | Jack... it's Dick... Do you want me to make the announcement?
Jack | No, no Dick. I must do it myself... (emotionally) it's my last chance with the BBC, I can't throw it away... I've got to do it ... for Joe-jums... for the kids... I've got to go through with it...
Dick | Good man. Now remember your announcer's training: deep breaths, and try not to think about what you're saying...
Jack | Good evening. This (a trace of superhuman effort in his voice) is BBC 1...
Joe-jums | Good luck, Jack.
Dick | Keep going, old boy.
Jack | It's... nine o'clock... and... time... for... the News... read by... Richard Baker.
| Cut to start of the 'Nine O'Clock News '.
Joe-jums | You've done it.
Dick | Congratulations, old man!
| Richard Baker is sitting at a desk. As Richard Baker speaks we hear no sounds apart from the sounds of celebration of the announcers - champagne corks popping, etc. At the beginning of the news Baker uses the gesture between sentences that we have seen Mr Orbiter use, plus other gestures. Behind him on the screen a collage of photos appear one after the other: Richard Nixon, Tony Armstrong-Jones, the White House, Princess Margaret, parliament, naked breasts, a scrubbing brush, a man with a stoat through his head, Margaret Thatcher, a lavatory, a Scotsman lying on his back with his knees drawn up, a corkscrew, Edward Heath, a pair of false teeth in a glass. Whilst these have been going on Baker has been making gestures starting with elbow-up gesture and getting progressively more obscure and intriguing. We don't hear him at all, we hear all the announcers having a party and congratulating Jack.
Joe-jums | Fantastic darling, you were brilliant. No, no, it was the best you ever did.
Jack | Thank God.
Joe-jums | It was absolutely super.
Dick | ... have a drink. For God's sake drink this...
Jack | Fantastic.
Dick | The least I could do - super - I must come over.
Jack | I can't tell you how much that means. (etc.)
| Eventually the voices stop and for the first time we hear Richard Baker's voice.
Baker | ... until the name Maudling is almost totally obscured. That is the ned of the nicro-not wens. And now it's time for the late night film.
| James Bond style opening titles with pictures of a pantomime horse.
| THE PANTOMIME HORSE IS A SECRET AGENT FILM. WRITTEN BY TALBOT ROTHWELL AND MIREILLE MATHIEU. BASED ON AN IDEA BY EDWARD VII. DIRECTED BY QUEEN JULIANA OF THE NETHERLANDS. PRODUCED BY SIR ALEC DOUGLAS-HOME AND KING HAAKON OF NORWAY. A CORPSE-HAKKON PRODUCTION.
| Cut to an idyllic scene - a boat drifting serenely on a river. A beautiful girl lies reclining in one end of the boat. A hoof appears round Carol's shoulders.
Girl | Oh pantomime horse, that was wonderful.
Dobbin | Would you like another glass?
Girl | No, no, I mustn't. It makes me throw up... oh, I'm so bleeding happy.
Dobbin | Oh, Simone!
Girl | Oh, pantomime horse.
| Cut to Graham in loony get up.
Loony | Then...
| The pantomime horse spins round and fires his revolver towards some trees overhanging the water. Another pantomime horse falls out of the tree into the water. A third pantomime horse scurries out from behind a bush and runs off into the undergrowth. Dobbin leaps out of the boat. The girl jumps after him. A car drives out of some bushes on to the road and accelerates away. The pantomime horse is in it. Dobbin and the girl leap into their own expensive sports car and give chase. Shots of exciting chase. After two or three shots of the cars chasing, the two pantomime horses are seen on two tandems, continuing the chase. Cut to them chasing each other on horseback. Cut to them chasing each other on rickshaws. Cut to them chasing each other on foot.
Voice Over | And now the English pantomime horse has very nearly caught up with the Russian pantomime horse, I think he's going to take him any moment now but what is this? What is this? (round the corner are waiting a pantomime goose and a pantomime Princess Margaret; the Russian pantomime horse runs past them and they leap on the English pantomime horse and a fight starts) Yes it's pantomime Princess Margaret and the pantomime goose and they're attacking the English pantomime horse and the Russian pantomime horse has got away. But who is this? (a car draws up and Terence Rattigan and the Duke of Kent and the RSM run up and join in the fighting; the Russians are joined by Heinz Sielmann and Peter Scott and Jacques Cousteau) My goodness me it's the Duke of Kent to the rescue...
| The fighting continues, behind, while the credits roll in front, reading as follows:
| TONY M. NYPHOT'S FLYING RISCCU SAW CODVENICE, TWITNER DNA FORDEPERM YB HAMRAG PACHMAN JOHN ECLES RICE LIED TORN JERSEY (5.5) MICHAEL LAPIN MARTY RIGELLI SOLA GAERAPPIN CAROL CLEVELAND ARCHSEER YB SUZAN DAVIES KAME PU MADELAINE GAFFNEY MUTESOCS HAZEL PETHIG MAINATIONS YB TERRY GILLIAM CUFFS LAVISEET BERNARD WILKIE PISHCARG BOB BLAGDEN MALE FANCIMARM ALAN FEATHERSTONE MOLE TRIFID RAY MILLICHOPE DOSUN RICHARD CHUBB LIGHTGIN JIMMY PURDIE REDENSIG IAN WATSON DECODURP YB IAN MACNAUGHTON B. B. LURCOO
Voice Over | (German accent) Here you see some English comic actors engaged in a life or death struggle with a rather weak ending. This is typical of the zany madcap world of the irresistible kooky funsters. The English pantomime horse wins and so is assured of a place in British history and a steady job in a merchant bank. Unfortunately, before his pension rights are assured, he catches bronchitis and dies, another victim of the need to finish these shows on time.
| Shot of pantomime horse in bed with his legs sticking in the air.
| CAPTION: 'ETH NED'